@@ -1,7 +1,8 @@
 package File::DataClass::Functions;
 
 use 5.010001;
-use strictures;
+use strict;
+use warnings;
 use feature 'state';
 
 use English               qw( -no_match_vars );
